@@ -20,7 +20,7 @@
 (*                                                                        *)
 (**************************************************************************)
 
- (* $Id: gText.ml 1499 2010-04-08 08:00:42Z garrigue $ *)
+ (* $Id$ *)
 
 open StdLabels
 open Gaux
@@ -153,6 +153,8 @@ type contents =
 class nocopy_iter it =
 object(self)
   val it = (it:text_iter)
+  method as_iter = it
+  method assign (r : nocopy_iter) = Iter.assign it r#as_iter
   method forward_char = Iter.forward_char it
   method backward_char = Iter.backward_char it
   method forward_chars n = Iter.forward_chars it n
@@ -369,6 +371,9 @@ class type buffer_signals_skel_type =
     method modified_changed : callback:(unit -> unit) -> GtkSignal.id
     method remove_tag :
       callback:(tag -> start:iter -> stop:iter -> unit) -> GtkSignal.id
+    method notify_cursor_position : callback:(int -> unit) -> GtkSignal.id
+    method notify_has_selection : callback:(bool -> unit) -> GtkSignal.id
+    method notify_tag_table : callback:(Gtk.text_tag_table -> unit) -> GtkSignal.id
   end
 
 class type ['b] buffer_signals_type = 
@@ -377,9 +382,11 @@ object ('a)
   method after : 'a
   method private connect :
     'c. ('b, 'c) GtkSignal.t -> callback:'c -> GtkSignal.id
+  method private notify :
+    'c. ('b, 'c) Gobject.property -> callback:('c -> unit) -> GtkSignal.id
 end
 
-class virtual buffer_signals_skel = 
+class virtual buffer_signals_skel =
 object(self)
   inherit text_buffer_sigs
   method apply_tag ~callback = 
